import * as i0 from '@angular/core';
import { Pipe, NgModule } from '@angular/core';

class Interval {
    constructor() {
        this.start = 0;
        this.end = 0;
    }
}
/*
 * Highlight some text
 * Usage:
 *   value | highlight:text_to_highlight
 * Example:
 *   {{ 'my text to highlight' | highlight:'text' }}
 *   formats to: 'my <mark>text</mark> to highlight'
 *   {{ 'my text to highlight':[ 'highlight', 'text'] }}
 *   formats to: 'my <mark>text</mark> to <mark>highlight</mark>'
*/
class HighlightPipe {
    highlight(value, word) {
        const startIndex = value.toLowerCase().indexOf(word.toLowerCase());
        if (startIndex !== -1) {
            const endLength = word.length;
            const matchingString = value.substr(startIndex, endLength);
            return value.replace(matchingString, '<mark>' + matchingString + '</mark>');
        }
        return '';
    }
    // retourne une liste d'interval où le mot est trouvé
    findWord(value, word) {
        const liste = [];
        const endLength = value.length;
        let startIndex = value.indexOf(word);
        while (startIndex > -1) {
            liste.push({ start: startIndex, end: startIndex + word.length });
            startIndex = value.indexOf(word, startIndex + word.length);
        }
        return liste;
    }
    transform(value, args) {
        if (args && value) {
            if (typeof args === 'string') {
                args = [args];
            }
            const lcValue = value.toLowerCase();
            // extrait tous les intervals des mots à marquer
            let intervals = [];
            for (const word of args) {
                if (word && word !== '') {
                    const found = this.findWord(lcValue, word.toLowerCase());
                    for (const f of found) {
                        intervals.push(f);
                    }
                }
            }
            if (intervals.length === 0) {
                return value;
            }
            // simplifie les intervals
            intervals = intervals
                .sort((a, b) => {
                return a.start - b.start || a.end - b.end;
            })
                .reduce((r, a) => {
                const last = r[r.length - 1] || {};
                if (last.start <= a.start && a.start <= last.end) {
                    if (last.end < a.end) {
                        last.end = a.end;
                    }
                    return r;
                }
                return r.concat(a);
            }, []);
            let resultat = '';
            let idx = 0;
            // highlight les intervals
            for (const interval of intervals) {
                if (interval.start > idx) {
                    resultat += value.substring(idx, interval.start);
                }
                const matchingString = value.substring(interval.start, interval.end);
                resultat += '<mark>' + matchingString + '</mark>';
                idx = interval.end;
            }
            resultat += value.substring(idx, value.length);
            return resultat;
        }
        return value;
    }
}
HighlightPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
HighlightPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightPipe, name: "highlight" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'highlight' }]
        }] });

class HighlightModule {
}
HighlightModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
HighlightModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightModule, declarations: [HighlightPipe], exports: [HighlightPipe] });
HighlightModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightModule, imports: [[]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.3", ngImport: i0, type: HighlightModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [],
                    exports: [HighlightPipe],
                    declarations: [HighlightPipe],
                }]
        }] });

/*
 * Public API Surface
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HighlightModule, HighlightPipe };
//# sourceMappingURL=gene6-highlight-pipe.js.map
